@@ -12,7 +12,7 @@ use Storable qw(dclone);
 use Test::Builder;
 use Test::Class::MethodInfo;
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
 my $Check_block_has_run;
 {
@@ -321,7 +321,7 @@ sub runtests {
 	TEST_OBJECT: foreach my $t (@tests) {
 		# SHOULD ALSO ALLOW NO_PLAN
 		next if $t =~ m/^\d+$/;
-		croak "$t not Test::Class or integer"
+		croak "$t is not Test::Class or integer"
 		    unless _isa_class( __PACKAGE__, $t );
         if (my $reason = $t->SKIP_CLASS) {
             _show_header($t, @tests);
@@ -335,7 +335,7 @@ sub runtests {
                 next TEST_OBJECT unless $method_passed;
             };
             my $class = ref($t);
-            my @setup = _get_methods($t, SETUP);
+            my @setup    = _get_methods($t, SETUP);
             my @teardown = _get_methods($t, TEARDOWN);
             foreach my $test (_get_methods($t, TEST)) { 
                 local $Current_method = $test;
@@ -1529,6 +1529,7 @@ Ask Bjorn Hansen,
 Chris Dolan,
 Chris Williams,
 Corion, 
+Cosimo Streppone,
 Daniel Berger,
 Dave O'Neill,
 David Cantrell,
@@ -1568,6 +1569,7 @@ Ted Carnahan,
 Terrence Brannon, 
 Tom Metro,
 Tony Bowden, 
+Tony Edwardson,
 William McKee, 
 various anonymous folk and all the fine people on perl-qa for their feedback, patches, suggestions and nagging.
 
